const AUTH_SERVER = 'https://auth.elijas.de';
const AUTH_HOSTNAME = new URL(AUTH_SERVER).hostname;

export function getJWTPayload(jwt: string) {
	const rawPayload = jwt.split('.')[1];

	const payload = JSON.parse(atob(rawPayload));

	return payload;
}

export function isJWTExpired(jwt: string) {
	const payload = getJWTPayload(jwt);

	if (payload.exp) {
		const exp = new Date(payload.exp * 1000);

		return Date.now() - 30 * 1000 > exp.valueOf();
	}
}

export default async function getJWT(client_id: string) {
	const button = document.createElement('button');
	button.innerText = 'Login';
	button.style.position = 'fixed';
	button.style.top = '1rem';
	button.style.right = '1rem';
	button.style.border = 'none';
	button.style.borderRadius = '4px';
	button.style.fontSize = '2rem';
	button.style.backgroundColor = '#1b75e3';
	button.style.zIndex = '500';
	button.style.height = '3rem';

	return new Promise<{ jwt: string; payload: { uid: string } }>((yes) => {
		button.onclick = () => {
			button.remove();

			const popup = open(
				AUTH_SERVER + '/popup',
				'Login',
				'left=100,right=100,width=400,height=600,location=no,toolbar=no,menubar=no'
			);

			let running = true;

			const ping = () => {
				popup.postMessage(
					{
						type: 'jwt',
						client_id: client_id,
					},
					AUTH_SERVER
				);
				if (running) setTimeout(() => ping(), 500);
			};

			const prms = new Promise<any>((yes, no) => {
				const onmsg = (msg) => {
					const hostname = new URL(msg.origin).hostname;
					if (hostname === AUTH_HOSTNAME) {
						//Legit answer
						if (msg.data.error) {
							no(new Error(msg.data.message));
						} else {
							const jwt = msg.data.jwt as string;
							const payload = getJWTPayload(jwt);
							yes({ jwt, payload });
						}
						clean();
					}
				};
				const clean = () => {
					removeEventListener('message', onmsg);
					running = false;
					if (!popup.closed) popup.close();
				};

				setTimeout(() => {
					no(new Error('Timeout'));
					clean();
				}, 300 * 1000);

				addEventListener('message', onmsg);
			});

			ping();

			yes(prms);
		};

		document.body.append(button);
	});
}
